@@ -27,7 +27,7 @@ The main features of the IRC client framework are:
     event-loop.
   * Decodes CTCP tagging correctly (hopefully); I haven't seen any
     other IRC client implementation that handles the CTCP
-    specification subtilties.
+    specification subtleties.
   * A kind of simple, single-server, object-oriented IRC client class
     that dispatches events to instance methods is included.
 
@@ -96,12 +96,15 @@ except Exception:
 class IRCError(Exception):
     "An IRC exception"
 
+
 class InvalidCharacters(ValueError):
     "Invalid characters were encountered in the message"
 
+
 class MessageTooLong(ValueError):
     "Message is too long"
 
+
 class PrioritizedHandler(
         collections.namedtuple('Base', ('priority', 'callback'))):
     def __lt__(self, other):
@@ -244,7 +247,7 @@ class Reactor(object):
         incoming data, if there are any.  If that seems boring, look
         at the process_forever method.
         """
-        log.log(logging.DEBUG-2, "process_once()")
+        log.log(logging.DEBUG - 2, "process_once()")
         sockets = self.sockets
         if sockets:
             (i, o, e) = select.select(sockets, [], [], timeout)
@@ -312,7 +315,7 @@ class Reactor(object):
         Returns 1 on success, otherwise 0.
         """
         with self.mutex:
-            if not event in self.handlers:
+            if event not in self.handlers:
                 return 0
             for h in self.handlers[event]:
                 if handler == h.callback:
@@ -355,7 +358,11 @@ class Reactor(object):
             self.connections.remove(connection)
             self._on_disconnect(connection.socket)
 
-_cmd_pat = "^(@(?P<tags>[^ ]*) )?(:(?P<prefix>[^ ]+) +)?(?P<command>[^ ]+)( *(?P<argument> .+))?"
+
+_cmd_pat = (
+    "^(@(?P<tags>[^ ]*) )?(:(?P<prefix>[^ ]+) +)?"
+    "(?P<command>[^ ]+)( *(?P<argument> .+))?"
+)
 _rfc_1459_command_regexp = re.compile(_cmd_pat)
 
 
@@ -365,6 +372,9 @@ class Connection(object):
     Base class for IRC connections.
     """
 
+    transmit_encoding = 'utf-8'
+    "encoding used for transmission"
+
     @abc.abstractproperty
     def socket(self):
         "The socket for this connection"
@@ -372,10 +382,15 @@ class Connection(object):
     def __init__(self, reactor):
         self.reactor = reactor
 
+    def encode(self, msg):
+        """Encode a message for transmission."""
+        return msg.encode(self.transmit_encoding)
+
 
 class ServerConnectionError(IRCError):
     pass
 
+
 class ServerNotConnectedError(ServerConnectionError):
     pass
 
@@ -398,7 +413,8 @@ class ServerConnection(Connection):
 
     # save the method args to allow for easier reconnection.
     @irc_functools.save_method_args
-    def connect(self, server, port, nickname, password=None, username=None,
+    def connect(
+            self, server, port, nickname, password=None, username=None,
             ircname=None, connect_factory=connection.Factory()):
         """Connect/reconnect to a server.
 
@@ -418,7 +434,8 @@ class ServerConnection(Connection):
 
         Returns the ServerConnection object.
         """
-        log.debug("connect(server=%r, port=%r, nickname=%r, ...)", server,
+        log.debug(
+            "connect(server=%r, port=%r, nickname=%r, ...)", server,
             port, nickname)
 
         if self.connected:
@@ -517,11 +534,13 @@ class ServerConnection(Connection):
         # process each non-empty line after logging all lines
         for line in self.buffer:
             log.debug("FROM SERVER: %s", line)
-            if not line: continue
+            if not line:
+                continue
             self._process_line(line)
 
     def _process_line(self, line):
-        event = Event("all_raw_messages", self.get_server_name(), None,
+        event = Event(
+            "all_raw_messages", self.get_server_name(), None,
             [line])
         self._handle_event(event)
 
@@ -571,16 +590,20 @@ class ServerConnection(Connection):
                     command = "ctcpreply"
 
                 m = list(m)
-                log.debug("command: %s, source: %s, target: %s, "
-                          "arguments: %s, tags: %s", command, source, target, m, tags)
+                log.debug(
+                    "command: %s, source: %s, target: %s, "
+                    "arguments: %s, tags: %s",
+                    command, source, target, m, tags)
                 event = Event(command, source, target, m, tags)
                 self._handle_event(event)
                 if command == "ctcp" and m[0] == "ACTION":
                     event = Event("action", source, target, m[1:], tags)
                     self._handle_event(event)
             else:
-                log.debug("command: %s, source: %s, target: %s, "
-                          "arguments: %s, tags: %s", command, source, target, [m], tags)
+                log.debug(
+                    "command: %s, source: %s, target: %s, "
+                    "arguments: %s, tags: %s",
+                    command, source, target, [m], tags)
                 event = Event(command, source, target, [m], tags)
                 self._handle_event(event)
 
@@ -596,8 +619,10 @@ class ServerConnection(Connection):
         if command == "mode":
             if not is_channel(target):
                 command = "umode"
-        log.debug("command: %s, source: %s, target: %s, "
-                  "arguments: %s, tags: %s", command, source, target, arguments, tags)
+        log.debug(
+            "command: %s, source: %s, target: %s, "
+            "arguments: %s, tags: %s",
+            command, source, target, arguments, tags)
         event = Event(command, source, target, arguments, tags)
         self._handle_event(event)
 
@@ -769,7 +794,6 @@ class ServerConnection(Connection):
         """Send a NAMES command."""
         self.send_items('NAMES', ','.join(always_iterable(channels)))
 
-
     def nick(self, newnick):
         """Send a NICK command."""
         self.send_items('NICK', newnick)
@@ -820,7 +844,7 @@ class ServerConnection(Connection):
         if '\n' in string:
             msg = "Carriage returns not allowed in privmsg(text)"
             raise InvalidCharacters(msg)
-        bytes = string.encode('utf-8') + b'\r\n'
+        bytes = self.encode(string) + b'\r\n'
         # According to the RFC http://tools.ietf.org/html/rfc2812#page-6,
         # clients should not transmit more than 512 bytes.
         if len(bytes) > 512:
@@ -1014,7 +1038,8 @@ class DCCConnection(Connection):
             self.socket.close()
             self.socket = conn
             self.connected = 1
-            log.debug("DCC connection from %s:%d", self.peeraddress,
+            log.debug(
+                "DCC connection from %s:%d", self.peeraddress,
                 self.peerport)
             self.reactor._handle_event(
                 self,
@@ -1039,7 +1064,8 @@ class DCCConnection(Connection):
 
             if len(self.buffer) > 2 ** 14:
                 # Bad peer! Naughty peer!
-                log.info("Received >16k from a peer without a newline; "
+                log.info(
+                    "Received >16k from a peer without a newline; "
                     "disconnecting.")
                 self.disconnect()
                 return
@@ -1052,7 +1078,8 @@ class DCCConnection(Connection):
         for chunk in chunks:
             log.debug("FROM PEER: %s", chunk)
             arguments = [chunk]
-            log.debug("command: %s, source: %s, target: %s, arguments: %s",
+            log.debug(
+                "command: %s, source: %s, target: %s, arguments: %s",
                 command, prefix, target, arguments)
             event = Event(command, prefix, target, arguments)
             self.reactor._handle_event(self, event)
@@ -1065,8 +1092,7 @@ class DCCConnection(Connection):
         """
         if self.dcctype == 'chat':
             text += '\n'
-        bytes = text.encode('utf-8')
-        return self.send_bytes(bytes)
+        return self.send_bytes(self.encode(text))
 
     def send_bytes(self, bytes):
         """
@@ -1117,7 +1143,8 @@ class SimpleIRCClient(object):
         self.connection = self.reactor.server()
         self.dcc_connections = []
         self.reactor.add_global_handler("all_events", self._dispatcher, -10)
-        self.reactor.add_global_handler("dcc_disconnect",
+        self.reactor.add_global_handler(
+            "dcc_disconnect",
             self._dcc_disconnect, -10)
 
     def _dispatcher(self, connection, event):
@@ -1217,6 +1244,7 @@ def is_channel(string):
     """
     return string and string[0] in "#&+!"
 
+
 def ip_numstr_to_quad(num):
     """
     Convert an IP number as an integer given in ASCII
@@ -1232,6 +1260,7 @@ def ip_numstr_to_quad(num):
     bytes = struct.unpack('BBBB', packed)
     return ".".join(map(str, bytes))
 
+
 def ip_quad_to_numstr(quad):
     """
     Convert an IP address string (e.g. '192.168.0.1') to an IP
@@ -1244,6 +1273,7 @@ def ip_quad_to_numstr(quad):
     packed = struct.pack('BBBB', *bytes)
     return str(struct.unpack('>L', packed)[0])
 
+
 class NickMask(six.text_type):
     """
     A nickmask (the source of an Event)
